resource "adguard_config" "config" {
  dhcp = {
    interface = "enp2s0"
    enabled   = true

    ipv4_settings = {
      gateway_ip     = "192.168.1.1"
      subnet_mask    = "255.255.252.0"
      range_start    = "192.168.1.10"
      range_end      = "192.168.1.199"
      lease_duration = 86400
    }

    static_leases = [
      {
        hostname = "tang"
        ip       = "192.168.1.53"
        mac      = "18:66:da:00:70:d8"
      },
      {
        hostname = "lounge-fire-tv"
        ip       = "192.168.1.13"
        mac      = "1c:12:b0:3c:da:e3"
      }
    ]
  }

  stats = {
    interval = 168
  }

  querylog = {
    interval = 24
  }

  dns = {
    rate_limit                 = 50
    blocked_response_ttl       = 30
    rate_limit_subnet_len_ipv4 = 22

    upstream_dns = [
      "https://dns.quad9.net/dns-query",
      "https://base.dns.mullvad.net/dns-query",
      "[/theorangeone.net/]${local.coredns_host}",
      "[/jakehoward.tech/]${local.coredns_host}"
    ]
  }
}

resource "adguard_user_rules" "user_rules" {
  rules = [
    "||elbisualp.theorangeone.net^",
  ]
}
